@@ -16,6 +16,8 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
+#include <utility>
+
 #include <QDockWidget>
 #include <QScreen>
 #include <QToolButton>
@@ -24,6 +26,7 @@
 #include <QTimer>
 #include <functional>
 #include <QGuiApplication>
+#include <QActionGroup>
 
 #ifdef HAVE_QDBUS
 #include <QtDBus/QtDBus>
@@ -41,6 +44,9 @@
 #include "qterminalapp.h"
 #include "dbusaddressable.h"
 
+#include <LayerShellQt/Shell>
+#include <LayerShellQt/Window>
+
 typedef std::function<bool(MainWindow&, QAction *)> checkfn;
 Q_DECLARE_METATYPE(checkfn)
 
@@ -165,6 +171,21 @@ MainWindow::~MainWindow()
 
 void MainWindow::enableDropMode()
 {
+    if (QGuiApplication::platformName() == QStringLiteral("wayland"))
+    {
+        winId();
+        if (QWindow *win = windowHandle())
+        {
+            if (LayerShellQt::Window* layershell = LayerShellQt::Window::get(win))
+            {
+                layershell->setLayer(LayerShellQt::Window::Layer::LayerOverlay);
+                layershell->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityOnDemand);
+                LayerShellQt::Window::Anchors anchors = {LayerShellQt::Window::AnchorTop};
+                layershell->setAnchors(anchors);
+            }
+        }
+    }
+
     setWindowFlags(Qt::Dialog | Qt::WindowStaysOnTopHint | Qt::CustomizeWindowHint);
 
     m_dropLockButton = new QToolButton(this);
@@ -536,7 +557,7 @@ void MainWindow::setupCustomDirs()
 
     dirs.removeDuplicates(); // QStandardPaths::locateAll() produces duplicates
 
-    for (const QString& dir : qAsConst(dirs)) {
+    for (const QString& dir : std::as_const(dirs)) {
         TermWidgetImpl::addCustomColorSchemeDir(dir + QLatin1String("/color-schemes"));
     }
     // FIXME: To be deprecated and then removed
@@ -599,6 +620,8 @@ void MainWindow::closeEvent(QCloseEvent *ev)
         // the session is ended explicitly (e.g., by ctrl-d); prompt doesn't make sense
         || consoleTabulator->terminalHolder()->findChildren<TermWidget*>().count() == 0)
     {
+        disconnect(m_bookmarksDock, &QDockWidget::visibilityChanged,
+                   this, &MainWindow::bookmarksDock_visibilityChanged); // prevent crash
         // #80 - do not save state and geometry in drop mode
         if (!m_dropMode) {
             if (Properties::Instance()->savePosOnExit) {
@@ -637,6 +660,8 @@ void MainWindow::closeEvent(QCloseEvent *ev)
     dia->setLayout(lay);
 
     if (dia->exec() == QDialog::Accepted) {
+        disconnect(m_bookmarksDock, &QDockWidget::visibilityChanged,
+                   this, &MainWindow::bookmarksDock_visibilityChanged);
         Properties::Instance()->mainWindowPosition = pos();
         Properties::Instance()->mainWindowSize = size();
         Properties::Instance()->mainWindowState = saveState();
@@ -738,7 +763,7 @@ void MainWindow::realign()
                         desktop.height() * Properties::Instance()->dropHeight / 100);
         g.moveCenter(desktop.center());
         // do not use 0 here - we need to calculate with potential panel on top
-        g.setTop(desktop.top());
+        g.moveTop(desktop.top());
         if (g != geometry()) {
             setGeometry(g);
         }
@@ -914,7 +939,7 @@ bool MainWindow::hasMultipleSubterminals(QAction *)
 
 bool MainWindow::hasIndexedTab(QAction *action)
 {
-    bool ok;
+    bool ok = false;
     const int index = action->property("tab").toInt(&ok);
     Q_ASSERT(ok);
     static_cast<void>(ok);
